;; Generated package description from org-gnosis.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "org-gnosis" "0.2.2.0.20260711.6" "Learning-focused note-taking for Gnosis" '((emacs "27.2") (emacsql "4.0.0") (compat "29.1.4.2")) :commit "1fdb8820f3bd14c1d7582a55ba53765d77663a3f" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("outlines" "extensions" "org-mode") :url "https://thanosapollo.org/projects/org-gnosis/")
